@@ -17,26 +17,17 @@
 
 from __future__ import annotations
 
-import logging
 import os
 from typing import TYPE_CHECKING, Any
 from urllib.parse import unquote
 
-from flask import flash, redirect, request, url_for
-from flask_appbuilder import BaseView
-from flask_appbuilder.api import expose
-
 from airflow.exceptions import AirflowException, TaskInstanceNotFound
 from airflow.models.dagrun import DagRun
 from airflow.models.taskinstance import TaskInstance, TaskInstanceKey, clear_task_instances
 from airflow.plugins_manager import AirflowPlugin
+from airflow.providers.common.compat.sdk import BaseOperatorLink, TaskGroup, XCom
 from airflow.providers.databricks.hooks.databricks import DatabricksHook
-from airflow.providers.databricks.version_compat import AIRFLOW_V_3_0_PLUS, BaseOperatorLink, TaskGroup, XCom
-
-if AIRFLOW_V_3_0_PLUS:
-    from airflow.providers.fab.www import auth
-else:
-    from airflow.www import auth  # type: ignore
+from airflow.providers.databricks.version_compat import AIRFLOW_V_3_0_PLUS
 from airflow.utils.log.logging_mixin import LoggingMixin
 from airflow.utils.state import TaskInstanceState
 
@@ -44,25 +35,17 @@ if TYPE_CHECKING:
     from sqlalchemy.orm.session import Session
 
     from airflow.models import BaseOperator
+    from airflow.providers.common.compat.sdk import Context
     from airflow.providers.databricks.operators.databricks import DatabricksTaskBaseOperator
-    from airflow.utils.context import Context
+    from airflow.sdk.types import Logger
 
 
 REPAIR_WAIT_ATTEMPTS = os.getenv("DATABRICKS_REPAIR_WAIT_ATTEMPTS", 20)
 REPAIR_WAIT_DELAY = os.getenv("DATABRICKS_REPAIR_WAIT_DELAY", 0.5)
 
 
-def get_auth_decorator():
-    if AIRFLOW_V_3_0_PLUS:
-        from airflow.api_fastapi.auth.managers.models.resource_details import DagAccessEntity
-    else:
-        from airflow.auth.managers.models.resource_details import DagAccessEntity
-
-    return auth.has_access_dag("POST", DagAccessEntity.RUN)
-
-
 def get_databricks_task_ids(
-    group_id: str, task_map: dict[str, DatabricksTaskBaseOperator], log: logging.Logger
+    group_id: str, task_map: dict[str, DatabricksTaskBaseOperator], log: Logger
 ) -> list[str]:
     """
     Return a list of all Databricks task IDs for a dictionary of Airflow tasks.
@@ -86,7 +69,64 @@ def get_databricks_task_ids(
 # TODO: Need to re-think on how to support the currently unavailable repair functionality in Airflow 3. Probably a
 # good time to re-evaluate this would be once the plugin functionality is expanded in Airflow 3.1.
 if not AIRFLOW_V_3_0_PLUS:
+    from flask import flash, redirect, request, url_for
+    from flask_appbuilder import BaseView
+    from flask_appbuilder.api import expose
+
     from airflow.utils.session import NEW_SESSION, provide_session
+    from airflow.www import auth
+
+    def get_auth_decorator():
+        from airflow.auth.managers.models.resource_details import DagAccessEntity
+
+        return auth.has_access_dag("POST", DagAccessEntity.RUN)
+
+    class RepairDatabricksTasks(BaseView, LoggingMixin):
+        """Repair databricks tasks from Airflow."""
+
+        default_view = "repair"
+
+        @expose("/repair_databricks_job/<string:dag_id>/<string:run_id>", methods=("GET",))
+        @get_auth_decorator()
+        def repair(self, dag_id: str, run_id: str):
+            return_url = self._get_return_url(dag_id, run_id)
+
+            tasks_to_repair = request.values.get("tasks_to_repair")
+            self.log.info("Tasks to repair: %s", tasks_to_repair)
+            if not tasks_to_repair:
+                flash("No tasks to repair. Not sending repair request.")
+                return redirect(return_url)
+
+            databricks_conn_id = request.values.get("databricks_conn_id")
+            databricks_run_id = request.values.get("databricks_run_id")
+
+            if not databricks_conn_id:
+                flash("No Databricks connection ID provided. Cannot repair tasks.")
+                return redirect(return_url)
+
+            if not databricks_run_id:
+                flash("No Databricks run ID provided. Cannot repair tasks.")
+                return redirect(return_url)
+
+            self.log.info("Repairing databricks job %s", databricks_run_id)
+            res = _repair_task(
+                databricks_conn_id=databricks_conn_id,
+                databricks_run_id=int(databricks_run_id),
+                tasks_to_repair=tasks_to_repair.split(","),
+                logger=self.log,
+            )
+            self.log.info("Repairing databricks job query for run %s sent", databricks_run_id)
+
+            self.log.info("Clearing tasks to rerun in airflow")
+
+            run_id = unquote(run_id)
+            _clear_task_instances(dag_id, run_id, tasks_to_repair.split(","), self.log)
+            flash(f"Databricks repair job is starting!: {res}")
+            return redirect(return_url)
+
+        @staticmethod
+        def _get_return_url(dag_id: str, run_id: str) -> str:
+            return url_for("Airflow.grid", dag_id=dag_id, dag_run_id=run_id)
 
     def _get_dag(dag_id: str, session: Session):
         from airflow.models.serialized_dag import SerializedDagModel
@@ -112,7 +152,7 @@ if not AIRFLOW_V_3_0_PLUS:
 
     @provide_session
     def _clear_task_instances(
-        dag_id: str, run_id: str, task_ids: list[str], log: logging.Logger, session: Session = NEW_SESSION
+        dag_id: str, run_id: str, task_ids: list[str], log: Logger, session: Session = NEW_SESSION
     ) -> None:
         dag = _get_dag(dag_id, session=session)
         log.debug("task_ids %s to clear", str(task_ids))
@@ -140,46 +180,45 @@ if not AIRFLOW_V_3_0_PLUS:
             raise TaskInstanceNotFound("Task instance not found")
         return ti
 
+    def _repair_task(
+        databricks_conn_id: str,
+        databricks_run_id: int,
+        tasks_to_repair: list[str],
+        logger: Logger,
+    ) -> int:
+        """
+        Repair a Databricks task using the Databricks API.
 
-def _repair_task(
-    databricks_conn_id: str,
-    databricks_run_id: int,
-    tasks_to_repair: list[str],
-    logger: logging.Logger,
-) -> int:
-    """
-    Repair a Databricks task using the Databricks API.
+        This function allows the Airflow retry function to create a repair job for Databricks.
+        It uses the Databricks API to get the latest repair ID before sending the repair query.
 
-    This function allows the Airflow retry function to create a repair job for Databricks.
-    It uses the Databricks API to get the latest repair ID before sending the repair query.
+        :param databricks_conn_id: The Databricks connection ID.
+        :param databricks_run_id: The Databricks run ID.
+        :param tasks_to_repair: A list of Databricks task IDs to repair.
+        :param logger: The logger to use for logging.
+        :return: None
+        """
+        hook = DatabricksHook(databricks_conn_id=databricks_conn_id)
 
-    :param databricks_conn_id: The Databricks connection ID.
-    :param databricks_run_id: The Databricks run ID.
-    :param tasks_to_repair: A list of Databricks task IDs to repair.
-    :param logger: The logger to use for logging.
-    :return: None
-    """
-    hook = DatabricksHook(databricks_conn_id=databricks_conn_id)
+        repair_history_id = hook.get_latest_repair_id(databricks_run_id)
+        logger.debug("Latest repair ID is %s", repair_history_id)
+        logger.debug(
+            "Sending repair query for tasks %s on run %s",
+            tasks_to_repair,
+            databricks_run_id,
+        )
 
-    repair_history_id = hook.get_latest_repair_id(databricks_run_id)
-    logger.debug("Latest repair ID is %s", repair_history_id)
-    logger.debug(
-        "Sending repair query for tasks %s on run %s",
-        tasks_to_repair,
-        databricks_run_id,
-    )
+        run_data = hook.get_run(databricks_run_id)
+        repair_json = {
+            "run_id": databricks_run_id,
+            "latest_repair_id": repair_history_id,
+            "rerun_tasks": tasks_to_repair,
+        }
 
-    run_data = hook.get_run(databricks_run_id)
-    repair_json = {
-        "run_id": databricks_run_id,
-        "latest_repair_id": repair_history_id,
-        "rerun_tasks": tasks_to_repair,
-    }
+        if "overriding_parameters" in run_data:
+            repair_json["overriding_parameters"] = run_data["overriding_parameters"]
 
-    if "overriding_parameters" in run_data:
-        repair_json["overriding_parameters"] = run_data["overriding_parameters"]
-
-    return hook.repair_run(repair_json)
+        return hook.repair_run(repair_json)
 
 
 def get_launch_task_id(task_group: TaskGroup) -> str:
@@ -294,7 +333,7 @@ class WorkflowJobRunLink(BaseOperatorLink, LoggingMixin):
 def store_databricks_job_run_link(
     context: Context,
     metadata: Any,
-    logger: logging.Logger,
+    logger: Logger,
 ) -> None:
     """
     Store the Databricks job run link in XCom during task execution.
@@ -368,7 +407,7 @@ class WorkflowJobRepairAllFailedLink(BaseOperatorLink, LoggingMixin):
                 children[child_id] = child
         return children
 
-    def get_tasks_to_run(self, ti_key: TaskInstanceKey, operator: BaseOperator, log: logging.Logger) -> str:
+    def get_tasks_to_run(self, ti_key: TaskInstanceKey, operator: BaseOperator, log: Logger) -> str:
         task_group = operator.task_group
         if not task_group:
             raise AirflowException("Task group is required for generating repair link.")
@@ -461,54 +500,6 @@ class WorkflowJobRepairSingleTaskLink(BaseOperatorLink, LoggingMixin):
         return url_for("RepairDatabricksTasks.repair", **query_params)
 
 
-class RepairDatabricksTasks(BaseView, LoggingMixin):
-    """Repair databricks tasks from Airflow."""
-
-    default_view = "repair"
-
-    @expose("/repair_databricks_job/<string:dag_id>/<string:run_id>", methods=("GET",))
-    @get_auth_decorator()
-    def repair(self, dag_id: str, run_id: str):
-        return_url = self._get_return_url(dag_id, run_id)
-
-        tasks_to_repair = request.values.get("tasks_to_repair")
-        self.log.info("Tasks to repair: %s", tasks_to_repair)
-        if not tasks_to_repair:
-            flash("No tasks to repair. Not sending repair request.")
-            return redirect(return_url)
-
-        databricks_conn_id = request.values.get("databricks_conn_id")
-        databricks_run_id = request.values.get("databricks_run_id")
-
-        if not databricks_conn_id:
-            flash("No Databricks connection ID provided. Cannot repair tasks.")
-            return redirect(return_url)
-
-        if not databricks_run_id:
-            flash("No Databricks run ID provided. Cannot repair tasks.")
-            return redirect(return_url)
-
-        self.log.info("Repairing databricks job %s", databricks_run_id)
-        res = _repair_task(
-            databricks_conn_id=databricks_conn_id,
-            databricks_run_id=int(databricks_run_id),
-            tasks_to_repair=tasks_to_repair.split(","),
-            logger=self.log,
-        )
-        self.log.info("Repairing databricks job query for run %s sent", databricks_run_id)
-
-        self.log.info("Clearing tasks to rerun in airflow")
-
-        run_id = unquote(run_id)
-        _clear_task_instances(dag_id, run_id, tasks_to_repair.split(","), self.log)
-        flash(f"Databricks repair job is starting!: {res}")
-        return redirect(return_url)
-
-    @staticmethod
-    def _get_return_url(dag_id: str, run_id: str) -> str:
-        return url_for("Airflow.grid", dag_id=dag_id, dag_run_id=run_id)
-
-
 class DatabricksWorkflowPlugin(AirflowPlugin):
     """
     Databricks Workflows plugin for Airflow.
