@@ -20,24 +20,20 @@
 
 from __future__ import annotations
 
-from collections.abc import Sequence
+from collections.abc import Callable, Sequence
 from datetime import datetime
 from functools import cached_property
-from typing import TYPE_CHECKING, Any, Callable
+from typing import TYPE_CHECKING, Any
 
 from databricks.sql.utils import ParamEscaper
 
 from airflow.exceptions import AirflowException
+from airflow.providers.common.compat.sdk import BaseSensorOperator
 from airflow.providers.common.sql.hooks.handlers import fetch_all_handler
 from airflow.providers.databricks.hooks.databricks_sql import DatabricksSqlHook
-from airflow.sensors.base import BaseSensorOperator
 
 if TYPE_CHECKING:
-    try:
-        from airflow.sdk.definitions.context import Context
-    except ImportError:
-        # TODO: Remove once provider drops support for Airflow 2
-        from airflow.utils.context import Context
+    from airflow.providers.common.compat.sdk import Context
 
 
 class DatabricksPartitionSensor(BaseSensorOperator):
@@ -226,6 +222,5 @@ class DatabricksPartitionSensor(BaseSensorOperator):
         self.log.debug("Partition sensor result: %s", partition_result)
         if partition_result:
             return True
-        else:
-            message = f"Specified partition(s): {self.partitions} were not found."
-            raise AirflowException(message)
+        message = f"Specified partition(s): {self.partitions} were not found."
+        raise AirflowException(message)
